@@ -129,22 +129,24 @@ END
    }
    $handle->clean_filehandle();
    ($stdout,$stderr)=$handle->cmd('hostname');
-   my $cmd='wget -d -qO- --keep-session-cookies '.
-      "--load-cookies /usr/share/tomcat8/cookies.txt ".
-      "--save-cookies /usr/share/tomcat8/cookies.txt ".
-      "--header='Upgrade-Insecure-Requests: 1' ".
-      "--header='DNT: 1' http://".$pbip.':8080/jenkins 2>&1';
-   ($stdout,$stderr)=$handle->cmd($cmd,'__display__');
+   my $cmd='wget -d -qO- '.
+      '-e robots=off '.
+      '--cookies=on --keep-session-cookies '.
+      '--save-cookies cookies.txt '.
+      '--header="Upgrade-Insecure-Requests: 1" '.
+      '--header="DNT: 1" http://'.$pbip.':8080/jenkins 2>&1';
+print "BEGIN_CMD=$cmd\n";
+   ($stdout,$stderr)=$handle->cmd($cmd);
+print "BEGIN_STDOUT=$stdout<== and BEGIN_STDERR=$stderr<==\n\n\n\n\n";
    my $session=$stdout;
    $stdout=~s/^.*(JSESSIONID=.*?);.*/$1/s;
    my $cookies=$stdout;
    $session=~s/^.*X-Jenkins-Session: (.*?)\n.*$/$1/s;
-   sleep 5;
-   $cmd='wget -d -qO- --content-on-error '.
-      #'--keep-session-cookies '.
-      #'--load-cookies /usr/share/tomcat8/cookies.txt '.
-      #'--save-cookies /usr/share/tomcat8/cookies.txt '.
-      '--header="Cookies: '.$cookies.'" '.
+   $cmd='sudo wget -d -qO- --content-on-error '.
+      '--random-wait --wait=3 '.
+      '--cookies=on --keep-session-cookies '.
+      '--load-cookies cookies.txt '.
+      '--save-cookies cookies.txt '.
       '--header="Accept: text/html,application/xhtml+xml,application/xml;'.
       'q=0.9,*/*;q=0.8" '.
       '--header="User-Agent: Mozilla/5.0 '.
@@ -154,8 +156,9 @@ END
       '--header="Referer: http://'.$pbip.':8080/jenkins/" '.
       'http://'.$pbip.':8080/jenkins/login?from=%2Fjenkins%2F';
 print "SESSION=$session\n";
-   ($stdout,$stderr)=$handle->cmd($cmd,'__display__');
-print "STDOUT=$stdout<========= and STDERR=$stderr<=========\n";
+print "LOGIN_CMD=$cmd\n";
+   ($stdout,$stderr)=$handle->cmd($cmd);
+print "LOGIN_STDOUT=$stdout<========= and LOGIN_STDERR=$stderr<=========\n\n\n\n\n";
    $cookies=$stderr;
    $cookies=~s/^.*(JSESSIONID=.*?);.*$/$1/s;
 print "COOKIE=$cookies<==\n";
@@ -208,10 +211,12 @@ print "CRUMB=$jenkins_crumb<==\n";
    );
 my $r=1;
 if ($r==0) {
-   my $session='';
    foreach my $ppath (@files) {
-      $cmd='wget -qO- --content-on-error --auth-no-challenge '.
-         '--header="Cookies: '.$cookies.'" '.
+      $cmd='wget -qO- --content-on-error '.
+         '--random-wait --wait=3 '.
+         '--cookies=on --keep-session-cookies '.
+         '--load-cookies cookies.txt '.
+         '--save-cookies cookies.txt '.
          '--level=1 '.
          '--header "Accept: text/html,application/xhtml+xml,application/xml;'.
          'q=0.9,*/*;q=0.8" '.
@@ -222,25 +227,24 @@ if ($r==0) {
          '--header="Referer: http://'.$pbip.':8080/jenkins/" '.
          'http://'.$pbip.':8080/jenkins/static/'.$session.$ppath;
       ($stdout,$stderr)=$handle->cmd($cmd);
-      sleep 1;
 print "STDOUT=$stdout<== AND STDERR=$stderr<== XXXXXXXXXXXXXX\n";
    }
 }
-   #($stdout,$stderr)=$handle->cmd("sudo ".
-   #   "sudo cat /usr/share/tomcat8/.jenkins/secrets/initialAdminPassword");
-   #my $adminpass=$stdout;
 print "PASS=$adminpass\n";
    my $data_crumb='from=%2Fjenkins%2F&j_username=admin&j_password='.
       $adminpass.'&Jenkins-Crumb='.$jenkins_crumb.'&json=%7B%22'.
       'from%22%3A+%22%2Fjenkins%2F%22%2C+%22j_username%22%3A+%22admin%22'.
       '%2C+%22j_password%22%3A+%22'.$adminpass.'%22%2C+%22Jenkins-Crumb%22%'.
       '3A+%22'.$jenkins_crumb.'%22%7D';
-   $cmd='wget -qO- --no-proxy --content-on-error --auth-no-challenge '.
+   $cmd='sudo wget -qO- --no-proxy --content-on-error --auth-no-challenge '.
+      '--random-wait --wait=3 '.
+      '--cookies=on --keep-session-cookies '.
+      '--load-cookies cookies.txt '.
+      '--save-cookies cookies.txt '.
       '--header="Accept: text/html,application/xhtml+xml,'.
       'application/xml;q=0.9,*/*;q=0.8" '.
-      '--header="Cookies: '.$cookies.'" '.
       '--header="DNT: 1" '.
-      '--header="Accept-Encoding: gzip, deflate, sdch" '.
+      '--header="Accept-Encoding: deflate, sdch" '.
       '--header="Accept-Language: en-US,en;q=0.5" '.
       '--header="Origin: http://'.$pbip.':8080" '.
       '--header="User-Agent: Mozilla/5.0 '.
@@ -251,23 +255,29 @@ print "PASS=$adminpass\n";
       '--referer="http://'.$pbip.':8080/jenkins/login?from=%2Fjenkins%2F" '.
       '--post-data="'.$data_crumb.'" '.
       'http://'.$pbip.':8080/jenkins/j_acegi_security_check';
-print "CMD=$cmd<==\n";
+print "ACEGI_CMD=$cmd<==\n";
+   $cookies=$stderr;
+   $cookies=~s/^.*(JSESSIONID=.*?);.*$/$1/s;
    ($stdout,$stderr)=$handle->cmd($cmd);
-   $cmd='wget -d -qO- --content-on-error '.
+print "ACEGI_STDOUT=$stdout and ACEGI_STDERR=$stderr<==\n";
+   $cmd='sudo wget -d -qO- --content-on-error '.
+      '--random-wait --wait=3 '.
+      '--cookies=on --keep-session-cookies '.
+      '--load-cookies cookies.txt '.
+      '--save-cookies cookies.txt '.
       '--header "Accept: text/html,application/xhtml+xml,application/xml;'.
       'q=0.9,*/*;q=0.8" '.
-      '--header="Cookies: '.$cookies.'" '.
       '--header="User-Agent: Mozilla/5.0 '.
       '(Windows NT 10.0; WOW64; rv:53.0) Gecko/20100101 Firefox/53.0" '.
-      '--header="Accept-Encoding: gzip, deflate, sdch" '.
+      '--header="Accept-Encoding: deflate, sdch" '.
       '--header="DNT: 1" '.
       '--header="Upgrade-Insecure-Requests: 1" '.
       '--header="Referer: http://'.$pbip.':8080/jenkins/login?from=%2Fjenkins%2F" '.
       '--header="Cache-Control: max-age=0" '.
-      #'--user=admin --password='.$adminpass.' '.
       'http://'.$pbip.':8080/jenkins/';
+print "FINAL_CMD=$cmd<==\n";
    ($stdout,$stderr)=$handle->cmd($cmd);
-print "FINALSTDOUT=$stdout<== and FINALSTDERR=$stderr<==FINALSTDERR\n";
+print "FINAL_STDOUT=$stdout<== and FINAL_STDERR=$stderr<==FINALSTDERR\n";
 
 #   my $json='{"dynamicLoad":true,"plugins":["cloudbees-folder","antisamy-markup-formatter","build-timeout","credentials-binding","timestamper","ws-cleanup","ant","gradle","workflow-aggregator","github-organization-folder","pipeline-stage-view","git","subversion","ssh-slaves","matrix-auth","pam-auth","ldap","email-ext","mailer"],"Jenkins-Crumb":"'.$jenkins_crumb.'"}';
 #   $cmd='wget --recursive --no-proxy --content-on-error '.
